Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Name string
Version string
Address string
Threads int `json:"threads"`
//reward is the amnount of tokens given to someone that "mines" a new block
Gas Gas
Wallet wallet.Config
Metrics Metrics
Transactions Transactions
Database persistencefactory.Config
API API
Log Log
P2P p2pfactory.Config
XCache p2padapter.XCache
GRPC GRPC
Trace trace.Config
}
func (*Config) DeepStructFields ¶
type Gas ¶
type Gas struct {
// Minimum amount of Wei per GAS to be paid for a transaction to be accepted for mining. Note: gasprice is listed in wei. Note 2: --gasprice is a “Legacy Option”
Price int `config:"gas-price"`
// Les mineurs sur le réseau décident de la limite de gaz du bloc.
// Il faut réintroduire une fonction de limite de gaz adaptative
Limit int `config:"gas-limit"`
// il existe une stratégie d'exploitation minière par défaut
// d'une limite de gaz de bloc minimale de 4 712 388 pour la plupart des clients
TargetMinLimit int `config:"targetgasMinlimit"`
TargetMaxLimit int `config:"targetgaslimit"`
// Amount of gas per block to target when sealing a new block
FloorTarget int `config:"gas-floor-target"`
// A cap on how large we will raise the gas limit per block due to transaction volume
Cap int `config:"gas-cap"`
}
type Transactions ¶
Click to show internal directories.
Click to hide internal directories.